@@ -205,7 +205,7 @@ const OverviewToolbar = new Lang.Class({
         this._selectionMenu.get_style_context().add_class('selection-menu');
         this.toolbar.set_custom_title(this._selectionMenu);
 
-        let selectionButton = new Gd.HeaderSimpleButton({ label: _("Done") });
+        let selectionButton = new Gd.HeaderSimpleButton({ label: _("Cancel") });
         this.toolbar.pack_end(selectionButton);
         selectionButton.get_style_context().add_class('suggested-action');
         selectionButton.connect('clicked', Lang.bind(this,
@@ -242,6 +242,7 @@ const OverviewToolbar = new Lang.Class({
     },
 
     _populateForOverview: function() {
+        this.toolbar.set_show_close_button(true);
         this._checkCollectionBackButton();
         this.addSearchButton();
 
@@ -277,6 +278,7 @@ const OverviewToolbar = new Lang.Class({
 
     _clearToolbar: function() {
         this._clearStateData();
+        this.toolbar.set_show_close_button(false);
 
         this.toolbar.get_style_context().remove_class('selection-mode');
         let children = this.toolbar.get_children();
